#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdio.h>
#include "em4095.h"

#define BAUD 9600UL

int uart_putc(char c, FILE *stream)
{
	loop_until_bit_is_set(UCSRA, UDRE);
	UDR = c;
	return 0;
}


int main()
{
	DDRC = 1<<PC5 | 1<<PC4 | 1<<PC2 | 1<<PC1; //Led, Led, Mod, Shd

	PORTC = 1<<PC4;

	UCSRB = 1<<TXEN;
	UCSRC = 1<<UCSZ1 | 1<<UCSZ0;
	
	UBRRH = (uint8_t) (F_CPU / (BAUD * 16) - 1) / 256;
	UBRRL = (uint8_t) (F_CPU / (BAUD * 16) - 1);

	fdevopen(uart_putc, NULL);

	TCCR0 = 1<<CS01 | 1<<CS00; //Timer/Counter0 prescaler 64
	MCUCR |= 1<<ISC00; //Any logical change on INT0 generates an interrupt request
	GICR |= 1<<INT0; //External interrupt request 0 enable (demod_out from RFID chip)

	sei();

	uint8_t tag[5];

	volatile uint32_t d;

	while (1)
	{
		if (em4095_read_tag(tag))
		{
			PORTC |= 1<<PC5;
			printf("\x04%.2X%.2X%.2X%.2X%.2X\x02", tag[0], tag[1], tag[2], tag[3], tag[4]);
			for (d=0; d<50000; d++);
		}
		else
			PORTC &= ~(1<<PC5);
	}
		
}
